==> polemarch-1.8.2.tar.gz: polemarch-1.8.2/polemarch/doc/html/_static/doctools.js <==
$u=_.noConflict();jQuery.urldecode=function(x){return decodeURIComponent(x).replace(/\+/g,' ');};jQuery.urlencode=encodeURIComponent;jQuery.getQueryParameters=function(s){if(typeof s==='undefined')
s=document.location.search;var parts=s.substr(s.indexOf('?')+1).split('&');var result={};for(var i=0;i<parts.length;i++){var tmp=parts[i].split('=',2);var key=jQuery.urldecode(tmp[0]);var value=jQuery.urldecode(tmp[1]);if(key in result)
result[key].push(value);else
result[key]=[value];}
return result;};jQuery.fn.highlightText=function(text,className){function highlight(node,addItems){if(node.nodeType===3){var val=node.nodeValue;var pos=val.toLowerCase().indexOf(text);if(pos>=0&&!jQuery(node.parentNode).hasClass(className)&&!jQuery(node.parentNode).hasClass("nohighlight")){var span;var isInSVG=jQuery(node).closest("body, svg, foreignObject").is("svg");if(isInSVG){span=document.createElementNS("http://www.w3.org/2000/svg","tspan");}else{span=document.createElement("span");span.className=className;}
span.appendChild(document.createTextNode(val.substr(pos,text.length)));node.parentNode.insertBefore(span,node.parentNode.insertBefore(document.createTextNode(val.substr(pos+text.length)),node.nextSibling));node.nodeValue=val.substr(0,pos);if(isInSVG){var rect=document.createElementNS("http://www.w3.org/2000/svg","rect");var bbox=node.parentElement.getBBox();rect.x.baseVal.value=bbox.x;rect.y.baseVal.value=bbox.y;rect.width.baseVal.value=bbox.width;rect.height.baseVal.value=bbox.height;rect.setAttribute('class',className);addItems.push({"parent":node.parentNode,"target":rect});}}}
else if(!jQuery(node).is("button, select, textarea")){jQuery.each(node.childNodes,function(){highlight(this,addItems);});}}
var addItems=[];var result=this.each(function(){highlight(this,addItems);});for(var i=0;i<addItems.length;++i){jQuery(addItems[i].parent).before(addItems[i].target);}
return result;};if(!jQuery.browser){jQuery.uaMatch=function(ua){ua=ua.toLowerCase();var match=/(chrome)[ \/]([\w.]+)/.exec(ua)||/(webkit)[ \/]([\w.]+)/.exec(ua)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua)||/(msie) ([\w.]+)/.exec(ua)||ua.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua)||[];return{browser:match[1]||"",version:match[2]||"0"};};jQuery.browser={};jQuery.browser[jQuery.uaMatch(navigator.userAgent).browser]=true;}
var Documentation={init:function(){this.fixFirefoxAnchorBug();this.highlightSearchWords();this.initIndexTable();if(DOCUMENTATION_OPTIONS.NAVIGATION_WITH_KEYS){this.initOnKeyListeners();}},TRANSLATIONS:{},PLURAL_EXPR:function(n){return n===1?0:1;},LOCALE:'unknown',gettext:function(string){var translated=Documentation.TRANSLATIONS[string];if(typeof translated==='undefined')
return string;return(typeof translated==='string')?translated:translated[0];},ngettext:function(singular,plural,n){var translated=Documentation.TRANSLATIONS[singular];if(typeof translated==='undefined')
return(n==1)?singular:plural;return translated[Documentation.PLURALEXPR(n)];},addTranslations:function(catalog){for(var key in catalog.messages)
this.TRANSLATIONS[key]=catalog.messages[key];this.PLURAL_EXPR=new Function('n','return +('+catalog.plural_expr+')');this.LOCALE=catalog.locale;},addContextElements:function(){$('div[id] > :header:first').each(function(){$('<a class="headerlink">\u00B6</a>').attr('href','#'+this.id).attr('title',_('Permalink to this headline')).appendTo(this);});$('dt[id]').each(function(){$('<a class="headerlink">\u00B6</a>').attr('href','#'+this.id).attr('title',_('Permalink to this definition')).appendTo(this);});},fixFirefoxAnchorBug:function(){if(document.location.hash&&$.browser.mozilla)
window.setTimeout(function(){document.location.href+='';},10);},highlightSearchWords:function(){var params=$.getQueryParameters();var terms=(params.highlight)?params.highlight[0].split(/\s+/):[];if(terms.length){var body=$('div.body');if(!body.length){body=$('body');}
window.setTimeout(function(){$.each(terms,function(){body.highlightText(this.toLowerCase(),'highlighted');});},10);$('<p class="highlight-link"><a href="javascript:Documentation.'+
'hideSearchWords()">'+_('Hide Search Matches')+'</a></p>').appendTo($('#searchbox'));}},initIndexTable:function(){var togglers=$('img.toggler').click(function(){var src=$(this).attr('src');var idnum=$(this).attr('id').substr(7);$('tr.cg-'+idnum).toggle();if(src.substr(-9)==='minus.png')
$(this).attr('src',src.substr(0,src.length-9)+'plus.png');else
$(this).attr('src',src.substr(0,src.length-8)+'minus.png');}).css('display','');if(DOCUMENTATION_OPTIONS.COLLAPSE_INDEX){togglers.click();}},hideSearchWords:function(){$('#searchbox .highlight-link').fadeOut(300);$('span.highlighted').removeClass('highlighted');},makeURL:function(relativeURL){return DOCUMENTATION_OPTIONS.URL_ROOT+'/'+relativeURL;},getCurrentURL:function(){var path=document.location.pathname;var parts=path.split(/\//);$.each(DOCUMENTATION_OPTIONS.URL_ROOT.split(/\//),function(){if(this==='..')
parts.pop();});var url=parts.join('/');return path.substring(url.lastIndexOf('/')+1,path.length-1);},initOnKeyListeners:function(){$(document).keyup(function(event){var activeElementType=document.activeElement.tagName;if(activeElementType!=='TEXTAREA'&&activeElementType!=='INPUT'&&activeElementType!=='SELECT'){switch(event.keyCode){case 37:var prevHref=$('link[rel="prev"]').prop('href');if(prevHref){window.location.href=prevHref;return false;}
case 39:var nextHref=$('link[rel="next"]').prop('href');if(nextHref){window.location.href=nextHref;return false;}}}});}};_=Documentation.gettext;$(document).ready(function(){Documentation.init();});

==> polemarch-2.0.0b2.tar.gz: polemarch-2.0.0b2/polemarch/doc/html/_static/doctools.js <==
$u=_.noConflict();jQuery.urldecode=function(x){return decodeURIComponent(x).replace(/\+/g,' ');};jQuery.urlencode=encodeURIComponent;jQuery.getQueryParameters=function(s){if(typeof s==='undefined')
s=document.location.search;var parts=s.substr(s.indexOf('?')+1).split('&');var result={};for(var i=0;i<parts.length;i++){var tmp=parts[i].split('=',2);var key=jQuery.urldecode(tmp[0]);var value=jQuery.urldecode(tmp[1]);if(key in result)
result[key].push(value);else
result[key]=[value];}
return result;};jQuery.fn.highlightText=function(text,className){function highlight(node,addItems){if(node.nodeType===3){var val=node.nodeValue;var pos=val.toLowerCase().indexOf(text);if(pos>=0&&!jQuery(node.parentNode).hasClass(className)&&!jQuery(node.parentNode).hasClass("nohighlight")){var span;var isInSVG=jQuery(node).closest("body, svg, foreignObject").is("svg");if(isInSVG){span=document.createElementNS("http://www.w3.org/2000/svg","tspan");}else{span=document.createElement("span");span.className=className;}
span.appendChild(document.createTextNode(val.substr(pos,text.length)));node.parentNode.insertBefore(span,node.parentNode.insertBefore(document.createTextNode(val.substr(pos+text.length)),node.nextSibling));node.nodeValue=val.substr(0,pos);if(isInSVG){var rect=document.createElementNS("http://www.w3.org/2000/svg","rect");var bbox=node.parentElement.getBBox();rect.x.baseVal.value=bbox.x;rect.y.baseVal.value=bbox.y;rect.width.baseVal.value=bbox.width;rect.height.baseVal.value=bbox.height;rect.setAttribute('class',className);addItems.push({"parent":node.parentNode,"target":rect});}}}
else if(!jQuery(node).is("button, select, textarea")){jQuery.each(node.childNodes,function(){highlight(this,addItems);});}}
var addItems=[];var result=this.each(function(){highlight(this,addItems);});for(var i=0;i<addItems.length;++i){jQuery(addItems[i].parent).before(addItems[i].target);}
return result;};if(!jQuery.browser){jQuery.uaMatch=function(ua){ua=ua.toLowerCase();var match=/(chrome)[ \/]([\w.]+)/.exec(ua)||/(webkit)[ \/]([\w.]+)/.exec(ua)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua)||/(msie) ([\w.]+)/.exec(ua)||ua.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua)||[];return{browser:match[1]||"",version:match[2]||"0"};};jQuery.browser={};jQuery.browser[jQuery.uaMatch(navigator.userAgent).browser]=true;}
var Documentation={init:function(){this.fixFirefoxAnchorBug();this.highlightSearchWords();this.initIndexTable();if(DOCUMENTATION_OPTIONS.NAVIGATION_WITH_KEYS){this.initOnKeyListeners();}},TRANSLATIONS:{},PLURAL_EXPR:function(n){return n===1?0:1;},LOCALE:'unknown',gettext:function(string){var translated=Documentation.TRANSLATIONS[string];if(typeof translated==='undefined')
return string;return(typeof translated==='string')?translated:translated[0];},ngettext:function(singular,plural,n){var translated=Documentation.TRANSLATIONS[singular];if(typeof translated==='undefined')
return(n==1)?singular:plural;return translated[Documentation.PLURALEXPR(n)];},addTranslations:function(catalog){for(var key in catalog.messages)
this.TRANSLATIONS[key]=catalog.messages[key];this.PLURAL_EXPR=new Function('n','return +('+catalog.plural_expr+')');this.LOCALE=catalog.locale;},addContextElements:function(){$('div[id] > :header:first').each(function(){$('<a class="headerlink">\u00B6</a>').attr('href','#'+this.id).attr('title',_('Permalink to this headline')).appendTo(this);});$('dt[id]').each(function(){$('<a class="headerlink">\u00B6</a>').attr('href','#'+this.id).attr('title',_('Permalink to this definition')).appendTo(this);});},fixFirefoxAnchorBug:function(){if(document.location.hash&&$.browser.mozilla)
window.setTimeout(function(){document.location.href+='';},10);},highlightSearchWords:function(){var params=$.getQueryParameters();var terms=(params.highlight)?params.highlight[0].split(/\s+/):[];if(terms.length){var body=$('div.body');if(!body.length){body=$('body');}
window.setTimeout(function(){$.each(terms,function(){body.highlightText(this.toLowerCase(),'highlighted');});},10);$('<p class="highlight-link"><a href="javascript:Documentation.'+
'hideSearchWords()">'+_('Hide Search Matches')+'</a></p>').appendTo($('#searchbox'));}},initIndexTable:function(){var togglers=$('img.toggler').click(function(){var src=$(this).attr('src');var idnum=$(this).attr('id').substr(7);$('tr.cg-'+idnum).toggle();if(src.substr(-9)==='minus.png')
$(this).attr('src',src.substr(0,src.length-9)+'plus.png');else
$(this).attr('src',src.substr(0,src.length-8)+'minus.png');}).css('display','');if(DOCUMENTATION_OPTIONS.COLLAPSE_INDEX){togglers.click();}},hideSearchWords:function(){$('#searchbox .highlight-link').fadeOut(300);$('span.highlighted').removeClass('highlighted');},makeURL:function(relativeURL){return DOCUMENTATION_OPTIONS.URL_ROOT+'/'+relativeURL;},getCurrentURL:function(){var path=document.location.pathname;var parts=path.split(/\//);$.each(DOCUMENTATION_OPTIONS.URL_ROOT.split(/\//),function(){if(this==='..')
parts.pop();});var url=parts.join('/');return path.substring(url.lastIndexOf('/')+1,path.length-1);},initOnKeyListeners:function(){$(document).keydown(function(event){var activeElementType=document.activeElement.tagName;if(activeElementType!=='TEXTAREA'&&activeElementType!=='INPUT'&&activeElementType!=='SELECT'&&activeElementType!=='BUTTON'&&!event.altKey&&!event.ctrlKey&&!event.metaKey&&!event.shiftKey){switch(event.keyCode){case 37:var prevHref=$('link[rel="prev"]').prop('href');if(prevHref){window.location.href=prevHref;return false;}
case 39:var nextHref=$('link[rel="next"]').prop('href');if(nextHref){window.location.href=nextHref;return false;}}}});}};_=Documentation.gettext;$(document).ready(function(){Documentation.init();});
